import numpy as np
import json, rowan, math

def invQuat(input_file, equivQ_file):
    with open(input_file) as g:
        data = json.load(g)

    with open(equivQ_file) as f:
        equiv_data = json.load(f)

    refQ = data["refQ"]
    orientations = data["Orientations"]
    equivQ = equiv_data["Equivalent_orientations"]
    sorted_orientations = []
    theta_array = []
    for i in range(len(orientations)):   # choosing particles one by one
        eqivQ = []
        for t in range(len(equivQ)):   # operation of each invariant quaternion on each particle
            eqivQ.append(rowan.normalize(rowan.multiply(orientations[i], equivQ[t])))   # Operating equivalent orientations on particle i

        angles = []
        for q1 in range(len(eqivQ)):   # Calculating angles among these quats
            quat_multiplication = rowan.multiply(rowan.conjugate(refQ), eqivQ[q1])
            quat_multiplication = rowan.normalize(quat_multiplication)
            angles.append(np.rad2deg(2*math.acos(quat_multiplication[0])))

        theta = np.min(angles)  # min angle
        theta_array.append(theta)
        for a in range(len(angles)):
            if angles[a] == theta:  # effective quaternion corresponding to the minimum angle
                sorted_orientations.append(eqivQ[a].tolist())
                break

    output_data = {}
    output_data["refQ"] = refQ
    output_data["equivQ"] = sorted_orientations
    output_data["Angles"] = theta_array
    with open('output.json', 'w') as outfile:
        json.dump(output_data, outfile, indent=4)


"""A setuptools based setup module."""

import pathlib
from setuptools import setup, find_packages

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
        name='invQ',
        version='0.1.1',
        description='A Python package to calculate the angles of quaternions with respect to a reference quaternion considering the point group symmetry of the rigid body',
        long_description=long_description,
        long_description_content_type='text/markdown',
        url='https://github.com/sumitavakundu007/invQ',
        author='Sumitava Kundu',
        author_email='kundusumitava@gmail.com',
        classifiers=[
            'Intended Audience :: Developers',
            'Topic :: Software Development :: Build Tools',
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9',
            ],
        keywords='sample, setuptools, development', 
        packages=['invQ'],
        python_requires='>=3.6',
        install_requires=['rowan'],
        
        entry_points={
                'console_scripts': [
                'invQ=invQ.calc_invQ:invQuat',
            ],
        },
        
        project_urls={  # Optional
            'Bug Reports': 'https://github.com/sumitavakundu007/invQ/issues',
            'Say Thanks!': 'http://saythanks.io/to/example',
            'Source': 'https://github.com/sumitavakundu007/invQ/',
            },
        )
